@@ -351,10 +351,12 @@ class Hosts(object):
                 existing_names.extend(item.names)
         existing_names = dedupe_list(existing_names)
         for entry in entries:
+            # Allow duplicates entries for addresses used for adblocking
             if entry.address in ('0.0.0.0', '127.0.0.1'):
                 if set(entry.names).intersection(existing_names):
                     if force:
-                        self.remove_all_matching(name=entry.names)
+                        for name in entry.names:
+                            self.remove_all_matching(name=name)
                         import_entries.append(entry)
                     else:
                         duplicate_count += 1
@@ -371,7 +373,8 @@ class Hosts(object):
                 if not force:
                     duplicate_count += 1
                 else:
-                    self.remove_all_matching(name=entry.names)
+                    for name in entry.names:
+                        self.remove_all_matching(name=name)
                     replaced_count += 1
                     import_entries.append(entry)
             else:
